@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: RapidApp-powered blog
 
-use RapidApp 1.3108;
+use RapidApp 1.3200;
 
 use Moose;
 extends 'RapidApp::Builder';
@@ -22,7 +22,7 @@ use YAML::XS 0.64 'LoadFile';
 use Rapi::Blog::Scaffold;
 use Rapi::Blog::Scaffold::Set;
 
-our $VERSION = 1.1004;
+our $VERSION = '1.1100';
 our $TITLE = "Rapi::Blog v" . $VERSION;
 
 has 'site_path',        is => 'ro', required => 1;
@@ -309,120 +309,7 @@ sub _build_base_config {
     },
     
     'Plugin::RapidApp::NavCore' => {
-      custom_navtree_nodes => [
-        {
-          text    => 'Taxonomies',
-          iconCls => 'icon-fa-cogs',
-          cls		=> 'pad-top-4px',
-          expand => \1,
-          children => [
-            {
-              text    => 'Tags',
-              iconCls => 'icon-tags-blue',
-              url     => '/adm/main/db/db_tag' 
-            },
-            {
-              text    => 'Categories',
-              iconCls => 'icon-images',
-              url     => '/adm/main/db/db_category' 
-            },
-            {
-              text    => 'Sections (Tree)',
-              iconCls => 'icon-sitemap-color',
-              url     => '/adm/sections' 
-            },
-            {
-              text    => 'Sections (Grid)',
-              iconCls => 'icon-chart-organisation',
-              url     => '/adm/main/db/db_section' 
-            },
-
-          ]
-        },
-        {
-          text     => 'Content',
-          iconCls  => 'icon-folder-table',
-          children => [
-            {
-              text    => 'Posts',
-              iconCls => 'icon-posts',
-              url     => '/adm/main/db/db_post' 
-            },
-            {
-              text    => 'Comments',
-              iconCls => 'icon-comments',
-              url     => '/adm/main/db/db_comment' 
-            },
-          ]
-        },
-        
-        {
-          text    => 'Index &amp; tracking tables',
-          iconCls => 'icon-database-gear',
-          children => [
-            {
-              text    => 'Post-Category Links',
-              iconCls => 'icon-logic-and',
-              url     => '/adm/main/db/db_postcategory' 
-            },
-            {
-              text    => 'Post-Tag Links',
-              iconCls => 'icon-logic-and-blue',
-              url     => '/adm/main/db/db_posttag' 
-            },
-            {
-              text    => 'Track Section-Posts',
-              iconCls => 'icon-table-relationship',
-              url     => '/adm/main/db/db_trksectionpost' 
-            },
-            {
-              text    => 'Track Section-Sections',
-              iconCls => 'icon-table-relationship',
-              url     => '/adm/main/db/db_trksectionsection' 
-            },
-          ]
-        },
-        
-        {
-          text    => 'Stats &amp; settings',
-          iconCls => 'icon-group-gear',
-          children => [
-            {
-              text    => 'Users',
-              iconCls => 'icon-users',
-              url     => '/adm/main/db/db_user' 
-            },
-            {
-              text    => 'Roles',
-              iconCls => 'ra-icon-user-prefs',
-              url     => '/adm/main/db/rapidapp_coreschema_role' 
-            },
-            {
-              text    => 'Hits',
-              iconCls => 'icon-world-gos',
-              url     => '/adm/main/db/db_hit' 
-            },
-            {
-              text    => 'Sessions',
-              iconCls => 'ra-icon-environment-network',
-              url     => '/adm/main/db/db_session' 
-            },
-            
-            {
-              text    => 'All Saved Views',
-              iconCls => 'ra-icon-data-views',
-              url     => '/adm/main/db/rapidapp_coreschema_savedstate' 
-            },
-            
-            {
-              text    => 'Default Views by Source',
-              iconCls => 'ra-icon-data-preferences',
-              url     => '/adm/main/db/rapidapp_coreschema_defaultview' 
-            },
-          ]
-        },
-        
-      ]
+      navtree_class => 'Rapi::Blog::Module::NavTree',
     },
     
     'Model::RapidApp::CoreSchema' => {
